<#

    .SYNOPSIS
    Library file

    .DESCRIPTION

    .PARAMETER

    .EXAMPLE

    .NOTES
    Author: Morten Rønborg
    Date: 11-09-2018
    Last Updated: 21-09-2018

#>

################################################
#Add assemblys
Add-Type -AssemblyName PresentationFramework
Add-Type -AssemblyName System.Windows.Forms
Function Write-Log
{
    param 
    (
        [Parameter(Mandatory=$true, HelpMessage="Provide a message")][string]$LogOutput,
        [Parameter(Mandatory=$true, HelpMessage="Provide the function name")][string]$FunctionName,
        [Parameter(Mandatory=$false, HelpMessage="Provide the scriptlinenumber")][string]$ScriptLine,
        [Parameter(Mandatory=$false, HelpMessage="Provide path, default is .\Logs")][string]$Path,
        [Parameter(Mandatory=$false, HelpMessage="Provide name for the logs")][string]$Name,
        [Parameter(Mandatory=$false, HelpMessage="Provide level, 1 = default, 2 = warning 3 = error")][ValidateSet(1, 2, 3)][int]$LogLevel = 1
    )

    #If the scriptline is not defined then use from the invocation
    If(!($ScriptLine)){
        $ScriptLine = $($MyInvocation.ScriptLineNumber)
    }

    if($LogOutput){

        #Date for the lognaming
        $FullLogName = ($Path + "\" + $Name + ".log")
        $FullSecodaryLogName = ($FullLogName).Replace(".log",".lo_")

        #If the log has reached over 20 mb then rename it
        if(Test-Path $FullLogName){
            if((Get-Item $FullLogName).Length -gt 5000kb){
                if(Test-Path $FullSecodaryLogName){
                    Remove-Item -Path $FullSecodaryLogName -force
                }
                Rename-Item -Path $FullLogName -NewName $FullSecodaryLogName
            }
        }

        #First check if folder/logfile excist, if not then create it
        if(!(test-path $Path)){
            New-Item -ItemType Directory -Force -Path $Path -ErrorAction SilentlyContinue
        }

        #Get current date and time to write to log
        $TimeGenerated = "$(Get-Date -Format HH:mm:ss).$((Get-Date).Millisecond)+000"

        #Construct the logline format
        $Line = '<![LOG[{0}]LOG]!><time="{1}" date="{2}" component="{3}" context="" type="{4}" thread="" file="">'

        #Define line
        $LineFormat = $logOutput, $TimeGenerated, (Get-Date -Format MM-dd-yyyy), "$($FunctionName):$($Scriptline)", $LogLevel

        #Append line
        $Line = $Line -f $LineFormat

        #Write log
        try {
            Write-Host ("[$($FunctionName):$($Scriptline)]" + $logOutput)
            $Line | Out-File -FilePath ($Path + "\" + $Name + ".log") -Append -NoClobber -Force -Encoding 'UTF8' -ErrorAction 'Stop'
        }
        catch {
            Write-Host "$_"
        }
    }
}
Function Get-MainWindowXAML{

    #Define the XAML
    [xml]$XAML = @"
    <Window x:Class="WpfApp2.MainWindow"
    xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation"
    xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml"
    xmlns:d="http://schemas.microsoft.com/expression/blend/2008"
    xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006"
    xmlns:local="clr-namespace:WpfApp2"
    mc:Ignorable="d"
    Title="Win32 app generator" Height="210" Width="525" Topmost="True" WindowStartupLocation="CenterScreen">
<Grid Margin="10,0,0,0">
    <TextBox x:Name="tbx_inputpath" HorizontalAlignment="Left" Height="23" Margin="83,57,0,0" TextWrapping="Wrap" Text="Input file" VerticalAlignment="Top" Width="387"/>
    <TextBox x:Name="tbx_outputpath" HorizontalAlignment="Left" Height="23" Margin="83,103,0,0" TextWrapping="Wrap" Text="Output folder" VerticalAlignment="Top" Width="387"/>
    <Button x:Name="btn_inputbrowse" Content="Browse" HorizontalAlignment="Left" Margin="3,57,0,0" VerticalAlignment="Top" Width="75" Height="23"/>
    <Button x:Name="btn_outputbrowse" Content="Browse" HorizontalAlignment="Left" Margin="3,103,0,0" VerticalAlignment="Top" Width="75" Height="23"/>
    <Button x:Name="btn_create" Content="Create" HorizontalAlignment="Left" Margin="195,134,0,0" VerticalAlignment="Top" Width="100" Height="29"/>
    <Label x:Name="fhfgh" Content=".intunewim generator" HorizontalAlignment="Left" Margin="10,14,0,0" VerticalAlignment="Top" Width="309" FontWeight="Bold"/>
    <Label x:Name="lbl_input" Content="Select file (EXE/MSI). Note that the folder content will be included." HorizontalAlignment="Left" Margin="83,33,0,0" VerticalAlignment="Top" FontSize="10"/>
    <Label x:Name="lbl_output" Content="Select output folder" HorizontalAlignment="Left" Margin="83,80,0,0" VerticalAlignment="Top" FontSize="10"/>
</Grid>
</Window>
"@

#Remove attributes
$CleanedXAML = Get-CleanXAML -XAML $XAML

#Return
Return $CleanedXAML

}

Function Get-CleanXAML{
    param(
        $XAML
    )

    #Attributes to remove
    $AttributesToRemove = @(
        'x:Class',
        'mc:Ignorable'
    )

    #Remove XML attributes that breaks PS
    foreach ($Attrib in $AttributesToRemove) {
        if ( $XAML.Window.GetAttribute($Attrib) ) {
                $XAML.Window.RemoveAttribute($Attrib)
        }
    }
    # [xml]$Form = $XAML -replace 'mc:Ignorable="d"','' -replace "x:N",'N'  -replace '^<Win.*', '<Window'
    #Return cleaned XML
    Return $XAML
}